@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine';
 
 use rlib '../../../..';
@@ -16,9 +16,9 @@ unless (@ISA) {
     use constant ALIASES    => qw(fin);
     use constant CATEGORY   => 'running';
     use constant SHORT_HELP => 'Step to end of current method (step out)';
-    use constant MIN_ARGS  => 0;  # Need at least this many
-    use constant MAX_ARGS  => 1;  # Need at most this many - undef -> unlimited.
-    use constant NEED_RUNNING => 1;
+    use constant MIN_ARGS   => 0;  # Need at least this many
+    use constant MAX_ARGS   => 1;  # Need at most this many 
+    use constant NEED_STACK => 1;
 EOE
 }
 
